import sqlite3
import tqdm

# Open the zillow.sqlite3 database
# you'll need the correct path to your database here.
con = sqlite3.connect("../../zillow.sqlite3")
 
cur = con.cursor()

cur.execute("SELECT name FROM PRAGMA_TABLE_INFO('orig_data') WHERE name LIKE '20%';")
colnames = cur.fetchall()

# Loop over each column name, split it into year, month, day, and 
# run the insert statement for each
# Here's the insert statement.

                    
for col in tqdm.tqdm(colnames):
    # col is: ('2000-01-31',) - a tuple with a string in it.
    # Split the string and convert the parts to integers
    col = col[0]
    year,month,day = (int(x) for x in col.split('-'))
    # and now execute it. The ? are replaced by the year,month,day,column_name.
    # The column name had to be inserted here for the execute statement to properly
    # fill in the other values.
    sql = f'''INSERT INTO HomeValueIndex (State,Region,Metro,County,Year,Month,Day,Value) 
              SELECT States.rowid,Regions.rowid,Metros.rowid,Counties.rowid,?,?,?,"{col}" FROM
              orig_data JOIN States ON orig_data.State=States.Postal
                        JOIN Metros ON orig_data.Metro=Metros.Name
                        JOIN Regions ON orig_data.RegionName=Regions.Name 
                        JOIN Counties ON orig_data.CountyName=Counties.Name'''  
    cur.execute(sql,(year,month,day))
 

# Commit the transaction
con.commit()    
con.close()
